

## Project
Easy access to the all the global envions like .env and os env

## Installing

```bash
    pip install os-env
```

Usage
=====

```py

    >>> import os-env
    >>> os-envs()
    '0.24.2'
```